=======
Credits
=======

Development Lead
----------------

* Robinson Beaucour <robinson.beaucour@cea.fr>
* Nicolas Lamaison <nicolas.lamaison@cea.fr>
* Thibaut Wissocq <thibaut.wissocq@cea.fr>

How to cite
-----------

.. code-block:: bibtex

    @misc{HeatPro,
            title = {HeatPro Python Package: Generate Heat Demand Load Profile for District Heating},
            author = {Beaucour, Robinson and Wissocq, Thibaut and Lamaison, Nicolas},
            year = {2024},
            url = {https://github.com/CEA-Liten/heatpro},
            note = {[Access Date]}
        }

Contributors
------------

None yet. Why not be the first?
